==> img_assist-4.4.x-1.x-dev.tar.gz: img_assist/properties.js <==
/* $Id: properties.js,v 1.1.2.1 2004/06/23 13:56:59 mathias Exp $
   Authored by Matt Westgate <drupal at asitis dot org>
*/

/**
 * When the thumbnail checkbox changes, enable/disable certain form elements
 */
function use_thumb(form) {
  if (form['edit-thumb'].checked) {
    form.height.disabled = true;
    form.width.disabled  = true;
    form['edit-aspect'].disabled = true;
  }
  else {
    form.height.disabled = false;
    form.width.disabled  = false;
    form['edit-aspect'].disabled = false;
  }
}

/**
 * Called when the 'insert image' button is pressed.
 */
function create_image(form) {
  insert_image(generate_image_tag(form));
}

/**
 * Maintain the width aspect ratio.
 */
function resizew(form, orig_width, orig_height) {
  new_width = form.width.value;

  if (form['edit-aspect'].checked == false) return null;

  if (new_width > orig_width) {
    change = new_width - orig_width;
    form.height.value = orig_height + change;
  }
  else {
    change = orig_width - new_width;
    new_height = orig_height - change;

    form.height.value = (new_height < 0) ? 0 : orig_height - change;
  }
}

/**
 * Maintain the height aspect ratio.
 */
function resizeh(form, orig_width, orig_height) {
  new_height = form.height.value;

  if (form['edit-aspect'].checked == false) return null;

  if (new_height > orig_height) {
    change = new_height - orig_height;
    form.width.value = orig_width + change;
  }
  else {
    change = orig_height - new_height;
    new_width = orig_width - change;

    form.width.value = (new_width < 0) ? 0 : orig_width - change;
  }
}

/**
 * Build the HTML image tag.
 */
function generate_image_tag(form) {
  var link = '';
  var attr = new Array();
  if (form['edit[img_path]'].value != '') {
    thumb = (form['edit-thumb'].checked) ? '&amp;thumb=1' : '';
    if (clean_url) {
      attr.push('src="img_assist/gen/'+form['edit[nid]'].value + thumb + '"');
      link = 'node/view/'+ form['edit[nid]'].value;
    }
    else {
      attr.push('src="?q=img_assist/gen/'+form['edit[nid]'].value + thumb + '"');
      link = '?q=node/view/'+ form['edit[nid]'].value;
    }
  }

  if (form['edit-thumb'].checked) {
    if (form['edit[thumbWidth]'].value != '')    attr.push('width="'+form['edit[thumbWidth]'].value+'"');
    if (form['edit[thumbHeight]'].value != '')   attr.push('height="'+form['edit[thumbHeight]'].value+'"');
  }
  else {
    if (form.width.value != '')  attr.push('width="'+form.width.value+'"');
    if (form.height.value != '') attr.push('height="'+form.height.value+'"');
  }
  if (form.alt.value != '')      attr.push('alt="'+form.alt.value+'"');
  if (form.border.value != '')   attr.push('style="border:'+form.border.value+'px solid black;"');
  if (form.vspace.value != '')   attr.push('vspace="'+form.vspace.value+'"');
  if (form.hspace.value != '')   attr.push('hspace="'+form.hspace.value+'"');
  if (form.align.value != '0')   attr.push('align="'+form.align.options[form.align.selectedIndex].text+'"');

  img = '<img '+ attr.join(' ') +' />';
  tpl = img_template; // Make a copy
  tpl = tpl.replace('%link', link);
  tpl = tpl.replace('%caption', form.caption.value);
  tpl = tpl.replace('%image', img);

  return tpl;
}

/**
 * Image preview window.
 */
function img_preview(form) {
  if (form['edit-thumb'].checked) {
    win_width  = parseInt(form['edit[thumbWidth]'].value);
    win_height = parseInt(form['edit[thumbHeight]'].value);
  }
  else {
    win_width  = parseInt(form.width.value);
    win_height = parseInt(form.height.value);
  }
  border = (parseInt(form.border.value) > 0) ? parseInt(form.border.value) : 1;
  win_width  += border * 2 + 18;
  win_height += border * 2 + 23;

  win = window.open('', 'img_preview', 'width='+ win_width +',height='+ win_height +',scrollbars=yes,status=no,resizable=yes');
  win.document.open('text/html', 'replace');
  win.document.write('<html><head><title>Preview Image</title>'+base_href+'</head><body>'+ generate_image_tag(form) +'</body></html>');
  win.document.close();
}

/**
 * Insert the code snippet into the parent textarea.
 */
function insert_image(snippet) {
  /* Inherit these values from the parent frameset */
  var myForm     = parent.myForm;
  var myTextarea = parent.myTextarea;
  var myDoc      = parent.myDoc;

  /* IE */
  if (myDoc.selection) {
    myTextarea.focus();
    cursor = myDoc.selection.createRange();
    cursor.text = snippet;
    //myForm.insert.focus();
  }
  /* Gecko-based engines: Mozilla, Camino, Firefox, Netscape */
  else if (myTextarea.selectionStart || myTextarea.selectionStart == "0") {
    var startPos  = myTextarea.selectionStart;
    var endPos    = myTextarea.selectionEnd;
    var body      = myTextarea.value;

    myTextarea.value = body.substring(0, startPos) + snippet + body.substring(endPos, body.length);
  }
  /* Worst case scenario: browsers that don't know about cursor position, Safari, OmniWeb, Konqueror */
  else {
    myTextarea.value += snippet;
  }
}

==> img_assist-4.5.x-1.x-dev.tar.gz: img_assist/properties.js <==
/* $Id: properties.js,v 1.4.2.3 2004/12/20 14:28:04 mathias Exp $
   Authored by Matt Westgate <drupal at asitis dot org>
*/

/**
 * When the thumbnail checkbox changes, enable/disable certain form elements
 */
function use_thumb(form) {
  if (form['edit-thumb'].checked) {
    form['edit[height]'].disabled = true;
    form['edit[width]'].disabled  = true;
    form['edit-aspect'].disabled = true;
  }
  else {
    form['edit[height]'].disabled = false;
    form['edit[width]'].disabled  = false;
    form['edit-aspect'].disabled = false;
  }
}

/**
 * Called when the 'insert image' button is pressed.
 */
function create_image(form) {
  insert_image(generate_image_tag(form));
}

/**
 * Maintain the width aspect ratio.
 */
function resizew(form, orig_width, orig_height) {
  if (form['edit-aspect'].checked == false) return null;
  form['edit[height]'].value = Math.round(orig_height * form['edit[width]'].value / orig_width);
}

/**
 * Maintain the height aspect ratio.
 */
function resizeh(form, orig_width, orig_height) {
  if (form['edit-aspect'].checked == false) return null;
  form['edit[width]'].value = Math.round(orig_width * form['edit[height]'].value / orig_height);
}

/**
 * Build the HTML image tag.
 */
function generate_image_tag(form) {
  var link = '';
  var attr = new Array();
  if (form['edit[img_path]'].value != '') {
    thumb = (form['edit-thumb'].checked) ? '&amp;thumb=1' : '';
    if (clean_url) {
      attr.push('src="img_assist/gen/'+form['edit[id]'].value + thumb + '"');
      link = 'node/'+ form['edit[nid]'].value;
    }
    else {
      attr.push('src="?q=img_assist/gen/'+form['edit[id]'].value + thumb + '"');
      link = '?q=node/'+ form['edit[nid]'].value;
    }
  }

  if (form['edit-thumb'].checked) {
    if (form['edit[thumbWidth]'].value  != '')   attr.push('width="'+form['edit[thumbWidth]'].value+'"');
    if (form['edit[thumbHeight]'].value != '')   attr.push('height="'+form['edit[thumbHeight]'].value+'"');
  }
  else {
    if (form['edit[width]'].value  != '') attr.push('width="'+form['edit[width]'].value+'"');
    if (form['edit[height]'].value != '') attr.push('height="'+form['edit[height]'].value+'"');
  }
  if (form['edit[alt]'].value    != '')   attr.push('alt="'+form['edit[alt]'].value+'"');

  img = '<img '+ attr.join(' ') +' />';
  tpl = img_template; // Make a copy
  tpl = tpl.replace('%link', link);
  tpl = tpl.replace('%caption', form['edit[caption]'].value);
  tpl = "\n" + tpl.replace('%image', img) + "\n";

  return tpl;
}

/**
 * Image preview window.
 */
function img_preview(form) {
  if (form['edit-thumb'].checked) {
    win_width  = parseInt(form['edit[thumbWidth]'].value);
    win_height = parseInt(form['edit[thumbHeight]'].value);
  }
  else {
    win_width  = parseInt(form['edit[width]'].value);
    win_height = parseInt(form['edit[height]'].value);
  }
  win_width  += 18 + 275;
  win_height += 23 + 225;

  var snippet = generate_image_tag(form);

  win = window.open('', 'img_preview', 'width='+ win_width +',height='+ win_height +',scrollbars=yes,status=no,resizable=yes');
  win.document.write('<html><head><title>Preview Image</title>'+base_href+'</head><body>'+ snippet +'<br /><textarea wrap="virtual" cols="45" rows="8">'+ snippet +'</textarea><p align="right">[ <a href="javascript:window.close()">X</a> ]</p></body></html>');
  win.document.close();
}

/**
 * Insert the code snippet into the parent textarea.
 */
function insert_image(snippet) {
  /* Inherit these values from the parent frameset */
  var myForm     = parent.myForm;
  var myTextarea = parent.myTextarea;
  var myDoc      = parent.myDoc;

  /* IE */
  if (myDoc.selection) {
    myTextarea.focus();
    cursor = myDoc.selection.createRange();
    cursor.text = snippet;
    //myForm.insert.focus();
  }
  /* Gecko-based engines: Mozilla, Camino, Firefox, Netscape */
  else if (myTextarea.selectionStart || myTextarea.selectionStart == "0") {
    var startPos  = myTextarea.selectionStart;
    var endPos    = myTextarea.selectionEnd;
    var body      = myTextarea.value;

    myTextarea.value = body.substring(0, startPos) + snippet + body.substring(endPos, body.length);
  }
  /* Worst case scenario: browsers that don't know about cursor position, Safari, OmniWeb, Konqueror */
  else {
    myTextarea.value += snippet;
  }
}
